﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.ServiceProcess;
using System.Diagnostics;
using LEADTOOLS_Express_Import;

namespace LEADTOOLS_Express_Import_Manager
{
    public partial class Form1 : Form
    {
        //Name of the service we want to control and monitor
        string svcName = "LEADTOOLS Express Import";

        ServiceController sc = new ServiceController();
        RegIO MyReg = new RegIO();
        
        public Form1()
        {
            InitializeComponent();
            sc.ServiceName = svcName;
        }

        private void btnStart_Click(object sender, EventArgs e)
        {
            //Try to Start the Service
            try
            {
                btnStart.Enabled = false;

                //If the service is in the "Paused" state issue a Continue command instead of Start
                if (sc.Status == ServiceControllerStatus.Paused)
                {
                    sc.Continue();
                }
                else
                    sc.Start();
            }
            catch (Exception ex)
            {
                btnStart.Enabled = true;
                MessageBox.Show(ex.Message);
            }
        }
        private void Form1_Load(object sender, EventArgs e)
        {
            svcTimer.Start();
            CheckStatus();
            if (MyReg.ReadAutoStart(svcName) == "2")
            checkBox1.Checked = true;
            else
            checkBox1.Checked = false;
        }

        private void btnStop_Click(object sender, EventArgs e)
        {
            //Try to Stop the service by issuing a Stop command
            try
            {
                btnStop.Enabled = false;
                sc.Stop();
            }
            catch (Exception ex)
            {
                btnStop.Enabled = true;
                MessageBox.Show(ex.Message);
            }
        }

        private void btnPause_Click(object sender, EventArgs e)
        {
            //Try to Pause the service
            try
            {
               btnPause.Enabled = false;
                sc.Pause();
            }
            catch (Exception ex)
            {
                btnPause.Enabled = true;
                MessageBox.Show(ex.Message);
            }
        }

        private void svcTimer_Tick(object sender, EventArgs e)
        {
            CheckStatus();
        }

        private void CheckStatus()
        {
            //Checks the status of the service and sets the status text, Icons, and Images to the appropriate selection

            if (DoesServiceExist(svcName))
            {
                try
                {
                    sc.Refresh();
                    txtStatus.Text = sc.Status.ToString();

                    switch (sc.Status)
                    {
                        case ServiceControllerStatus.Running:
                            picStatus.Image = Properties.Resources.LEAD_Start;
                            notifyManager.Icon = Properties.Resources.LEAD_Start_Icon;
                            this.Icon = Properties.Resources.LEAD_Start_Icon;

                            mnuStop.Enabled = true;
                            btnStop.Enabled = true;

                            btnStart.Enabled = false;
                            mnuStart.Enabled = false;

                            mnuPause.Enabled = true;
                            btnPause.Enabled = true;

                            btnConfig.Enabled = false;
                            break;

                        case ServiceControllerStatus.Stopped:
                            picStatus.Image = Properties.Resources.LEAD_Stop;
                            notifyManager.Icon = Properties.Resources.LEAD_Stop_Icon;
                            this.Icon = Properties.Resources.LEAD_Stop_Icon;

                            mnuStop.Enabled = false;
                            btnStop.Enabled = false;

                            mnuStart.Enabled = true;
                            btnStart.Enabled = true;

                            mnuPause.Enabled = false;
                            btnPause.Enabled = false;

                            btnConfig.Enabled = true;
                            break;

                        case ServiceControllerStatus.Paused:
                            picStatus.Image = Properties.Resources.LEAD_Pause;
                            notifyManager.Icon = notifyManager.Icon = Properties.Resources.LEAD_Pause_Icon;
                            this.Icon = Properties.Resources.LEAD_Pause_Icon;

                            mnuStop.Enabled = true;
                            btnStop.Enabled = true;

                            mnuStart.Enabled = true;
                            btnStart.Enabled = true;

                            mnuPause.Enabled = false;
                            btnPause.Enabled = false;

                            btnConfig.Enabled = false;
                            break;
                    }
                }
                catch (Exception ex)
                {
                    MessageBox.Show(ex.Message);
                    throw;
                }
            }
            else
            {
                picStatus.Image = Properties.Resources.LEAD_Stop;
                notifyManager.Icon = Properties.Resources.LEAD_Stop_Icon;
                this.Icon = Properties.Resources.LEAD_Stop_Icon;
                this.txtStatus.Text = "No Service Present";

                mnuStop.Enabled = false;
                btnStop.Enabled = false;

                mnuStart.Enabled = false;
                btnStart.Enabled = false;

                mnuPause.Enabled = false;
                btnPause.Enabled = false;

                checkBox1.Enabled = false;
                btnConfig.Enabled = true;
            }
        }

        private void btnEvent_Click(object sender, EventArgs e)
        {
            //Launches Event Viewer
            Process.Start("eventvwr","/c:Application");
        }

        private void btnConfig_Click(object sender, EventArgs e)
        {
            //Displays the Configuration Form
            frmSetup SetupForm = new frmSetup();
            SetupForm.Show();
        }

        //Method to determine if a specific service exists on the local machine
        bool DoesServiceExist(string serviceName)
        {
            ServiceController[] services = ServiceController.GetServices("localhost");
            var service = services.FirstOrDefault(s => s.ServiceName == serviceName);
            return service != null;
        }

        private void checkBox1_CheckedChanged(object sender, EventArgs e)
        {
            if (checkBox1.Checked)
                MyReg.SaveAutoStart(svcName, "2");
            else
                MyReg.SaveAutoStart(svcName, "3");
        }

        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            //If the user closes the form, it instead goes to the system tray instead of exiting the application
            if (e.CloseReason == CloseReason.UserClosing)
            {
                e.Cancel = true;

                if(notifyManager.Visible == false)
                    notifyManager.Visible = true;
                    
                Hide();
            }
        }

        private void mnuExit_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        private void mnuStart_Click(object sender, EventArgs e)
        {
            try
            {
                btnStart.Enabled = false;

                if (sc.Status == ServiceControllerStatus.Paused)
                {
                    sc.Continue();
                }
                else
                    sc.Start();

            }
            catch (Exception ex)
            {
                btnStart.Enabled = true;
                MessageBox.Show(ex.Message);
            }
        }

        private void mnuPause_Click(object sender, EventArgs e)
        {
            try
            {
                btnPause.Enabled = false;
                sc.Pause();
            }
            catch (Exception ex)
            {
                btnPause.Enabled = true;
                MessageBox.Show(ex.Message);
            }
        }

        private void mnuStop_Click(object sender, EventArgs e)
        {
            try
            {
                btnStop.Enabled = false;
                sc.Stop();
            }
            catch (Exception ex)
            {
                btnStop.Enabled = true;
                MessageBox.Show(ex.Message);
            }
        }
        private void notifyManager_MouseDoubleClick(object sender, MouseEventArgs e)
        {
            this.Show();
            notifyManager.Visible = false;
        }
    }
}
