﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Win32;
using System.Windows.Forms;

namespace LEADTOOLS_Express_Import
{
    class RegIO
    {
        string RegPath;
        RegistryKey RegKey;

        string _server = "";
        string _database = "";
        string _username = "";
        string _password = "";
        string _filePath = "";
        string _imageStore = "";

        //Set up the properties we wil need to get and set from the registry

        public  string Server
        {
            get { return _server; }
        }

        public  string Database
        {
            get { return _database; }
        }

        public  string UserName
        {
            get { return _username; }
        }

        public  string Password
        {
            get { return _password; }
        }
        public  string FilePath
        {
            get { return _filePath; }
        }
        public string ImageStore
        {
            get { return _imageStore; }
        }
        
        //Method for saving our settings to the windows registry
        public void Save(string company, string Name, string server, string database, string username, string password, string FilePath, string ImageStore)
        {
            //Setting the Registry path based on the Company Name, Software Name, and Bit of the OS
            try
            {
                if (System.Environment.Is64BitOperatingSystem)
                {
                    RegPath = @"SOFTWARE\Wow6432Node\" + company + @"\" + Name;
                    RegKey = Registry.LocalMachine.OpenSubKey(RegPath);

                    //If the Registry key does not exist on the system, then build it based on the parameters specified
                    if (RegKey == null)
                    {
                        RegKey = Registry.LocalMachine.OpenSubKey(@"SOFTWARE\Wow6432Node\",true);
                        RegKey.CreateSubKey(company);
                        RegKey = Registry.LocalMachine.OpenSubKey(@"SOFTWARE\Wow6432Node\" + company, true);
                        RegKey.CreateSubKey(Name);
                        RegKey = Registry.LocalMachine.OpenSubKey(@"SOFTWARE\Wow6432Node\" + company + @"\" + Name, true);
                    }
                }
                else
                {
                    RegPath = @"SOFTWARE\" + company + @"\" + Name;
                    RegKey = Registry.LocalMachine.OpenSubKey(RegPath);

                    //If the Registry key does not exist on the system, then build it based on the parameters specified
                    if (RegKey == null)
                    {
                        RegKey = Registry.LocalMachine.OpenSubKey("SOFTWARE", true);
                        RegKey.CreateSubKey(company);
                        RegKey = Registry.LocalMachine.OpenSubKey(@"SOFTWARE\" + company, true);
                        RegKey.CreateSubKey(Name);
                        RegKey = Registry.LocalMachine.OpenSubKey(@"SOFTWARE\" + company + @"\" + Name, true);
                    }
                }

                //Now that the Registry entry is verified, start setting the values
                RegKey = Registry.LocalMachine.OpenSubKey(RegPath, true);

                RegKey.SetValue("Server Name", server);
                RegKey.SetValue("Database Name", database);
                RegKey.SetValue("Username", username);
                RegKey.SetValue("Password", password);
                RegKey.SetValue("File Path", FilePath);
                RegKey.SetValue("Image Store", ImageStore);

                //After setting the registry values, close the registry key
                RegKey.Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }
        }

        //Method for reading our settings from the windows registry
        public void Read(string company, string Name)
        {
            //Make sure we are reading the registry from the correct location based on the variables specified
            if (System.Environment.Is64BitOperatingSystem)
            {
                RegPath = @"SOFTWARE\Wow6432Node\" +company + @"\" + Name;
            }
            else
            {
                RegPath = @"SOFTWARE\" + company + @"\" + Name;
            }

            RegKey = Registry.LocalMachine.OpenSubKey(RegPath);

            //As long as there is a value in the registry, set the corresponding registry keys to the property values
            if (RegKey != null)
                _server = RegKey.GetValue("Server Name", "").ToString();

            if (RegKey != null)
            _database = RegKey.GetValue("Database Name","").ToString();

            if (RegKey != null)
            _username = RegKey.GetValue("Username", "").ToString();

            if (RegKey != null)
            _password = RegKey.GetValue("Password", "").ToString();

            if (RegKey != null)
            _filePath = RegKey.GetValue("File Path", "").ToString();

            if (RegKey != null)
                _imageStore = RegKey.GetValue("Image Store", "").ToString();

            if (RegKey != null)
                RegKey.Close();
        }

        //Separate Method for saving the "Auto Start Service with OS" option within the Registry
        public void SaveAutoStart(string Name, string state)
        {
            try
            {
                RegPath = @"System\CurrentControlSet\Services\" + Name;
                RegKey = Registry.LocalMachine.OpenSubKey(RegPath);

                    if (RegKey != null)
                    {
                        RegKey = Registry.LocalMachine.OpenSubKey(RegPath, true);
                        RegKey.SetValue("Start", state, RegistryValueKind.DWord);
                    }
                    RegKey.Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }
        }

        //Separate Method for reading the "Auto Start Service with OS" option within the Registry
        public string ReadAutoStart(string Name)
        {
            string Value = "";

            RegPath = @"System\CurrentControlSet\Services\" + Name;

            RegKey = Registry.LocalMachine.OpenSubKey(RegPath);

            if (RegKey != null)
            {
                Value = RegKey.GetValue("Start", "").ToString();
                RegKey.Close();
                return Value;
            }
            else
            {
                return "0";
            }
        }
    }
}
